"use strict";

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var kafka = require('kafka-node');

var THRIFT = require('zipkin-encoder-thrift');

var _require = require('zipkin'),
    JSON_V2 = _require.jsonEncoder.JSON_V2;

module.exports =
/*#__PURE__*/
function () {
  function KafkaLogger(options) {
    var _this = this;

    _classCallCheck(this, KafkaLogger);

    var clientDefaults = {
      clientId: 'zipkin-transport-kafka',
      zkOpts: {}
    };
    var clientOpts = Object.assign({}, clientDefaults, options.clientOpts || {});
    var producerDefaults = {
      requireAcks: 0
    };
    /* eslint-disable no-console */

    var log = options.log || console;
    var producerOpts = Object.assign({}, producerDefaults, options.producerOpts || {});

    this.onError = options.onError || function (err) {
      log.error(err);
    };

    if (typeof options.encoder === 'undefined' || options.encoder === THRIFT) {
      this.encoder = THRIFT;
    } else if (options.encoder === JSON_V2) {
      // Temporarily do singleton list messages until logic from the http logger is extracted
      this.encoder = {
        encode: function encode(span) {
          return "[".concat(JSON_V2.encode(span), "]");
        }
      };
    } else {
      throw new Error('Unsupported encoder. Valid choices are THRIFT and JSON_V2.');
    }

    this.topic = options.topic || 'zipkin';

    if (clientOpts.connectionString) {
      this.client = new kafka.Client(clientOpts.connectionString, clientOpts.clientId, clientOpts.zkOpts);
    } else {
      this.client = new kafka.KafkaClient(clientOpts);
    }

    this.producer = new kafka.HighLevelProducer(this.client, producerOpts);
    this.producerState = 'pending';
    this.producer.on('ready', function () {
      _this.producerState = 'ready';

      _this.producer.removeAllListeners('ready');
    });
    this.producer.on('error', this.onError);
    this.client.on('error', this.onError);
  }

  _createClass(KafkaLogger, [{
    key: "logSpan",
    value: function logSpan(span) {
      var _this2 = this;

      var sendSpan = function sendSpan(data) {
        _this2.producer.send([{
          topic: _this2.topic,
          messages: data
        }], function (err) {
          if (err) {
            _this2.onError(err);
          }
        });
      };

      try {
        var encodedSpan = this.encoder.encode(span);

        if (this.producerState === 'ready') {
          sendSpan(encodedSpan);
        } else {
          this.producer.on('ready', function () {
            _this2.producerState = 'ready';
            sendSpan(encodedSpan);

            _this2.producer.removeAllListeners('ready');
          });
        }
      } catch (err) {
        this.onError(err);
      }
    }
  }, {
    key: "close",
    value: function close() {
      var _this3 = this;

      return new Promise(function (resolve) {
        return _this3.client.close(resolve);
      });
    }
  }]);

  return KafkaLogger;
}();